@@ -19,7 +19,7 @@ class DKConnection():
     def OrderRunInfo(self, kitchen, order_run_id):
         url = "https://%s/v2/order/details/%s" % ( self.hostname, kitchen)
         headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer ' + self.token}
-        payload = {'serving_hid' : order_run_id, 'testresults': True}
+        payload = {'serving_hid' : order_run_id, 'testresults': True, "schedule": "now"}
         r = requests.post(url, headers=headers, data=json.dumps(payload))
         if "does not exist." in r.text:
             raise Exception("Order run id %s not found." % order_run_id )
